pub struct Path {
pub segments: Vec<PathSegment>,
}Expand description
A fully qualified path.
Fields
segments: Vec<PathSegment>The path segments.
Implementations
Sourceimpl Path
impl Path
Sourcepub fn from_string_with_separator(
string: &str,
separator: impl AsRef<str>,
) -> Self
pub fn from_string_with_separator( string: &str, separator: impl AsRef<str>, ) -> Self
Get Path from a string with a specified separator.
Sourcepub fn to_string_with_separator(&self, separator: impl AsRef<str>) -> String
pub fn to_string_with_separator(&self, separator: impl AsRef<str>) -> String
Convert the Path to a string with a specified separator.
Sourcepub fn first(&self) -> &PathSegment
pub fn first(&self) -> &PathSegment
Get the first segment’s reference.
Sourcepub fn first_mut(&mut self) -> &mut PathSegment
pub fn first_mut(&mut self) -> &mut PathSegment
Get the first segment’s mutable reference.
Sourcepub fn last(&self) -> &PathSegment
pub fn last(&self) -> &PathSegment
Get the last segment’s reference.
Sourcepub fn last_mut(&mut self) -> &mut PathSegment
pub fn last_mut(&mut self) -> &mut PathSegment
Get the last segment’s mutable reference.
Sourcepub fn without_first(self) -> Self
pub fn without_first(self) -> Self
Returns the Path without the first segment.
Sourcepub fn without_last(self) -> Self
pub fn without_last(self) -> Self
Returns the Path without the last segment.
Sourcepub fn pop_front(&mut self) -> Option<PathSegment>
pub fn pop_front(&mut self) -> Option<PathSegment>
Removes the first element and returns it, or None if the Path is empty.
Sourcepub fn pop_back(&mut self) -> Option<PathSegment>
pub fn pop_back(&mut self) -> Option<PathSegment>
Removes the last element and returns it, or None if the Path is empty.
Sourcepub fn push_front(&mut self, segment: impl Into<PathSegment>)
pub fn push_front(&mut self, segment: impl Into<PathSegment>)
Pushes the given segment onto the end of the Path.
Sourcepub fn push_back(&mut self, segment: impl Into<PathSegment>)
pub fn push_back(&mut self, segment: impl Into<PathSegment>)
Pushes the given segment onto the end of the Path.